@@ -20,8 +20,8 @@
  *  General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public
- *  License along with this software; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ *  License along with this software. If not, see
+ *  <http://www.gnu.org/licenses/>.
  *
  */
 
@@ -70,8 +70,11 @@ void ImageLineList::SetFilename(wxString newFilename)
 {
     m_filename=newFilename;
     std::string filenamestring(newFilename.mb_str(HUGIN_CONV_FILENAME));
-    m_panoImage=new HuginBase::SrcPanoImage(filenamestring);
-    if(m_panoImage->getExifCropFactor()<=0)
+    m_panoImage=new HuginBase::SrcPanoImage;
+    m_panoImage->setFilename(filenamestring);
+    m_panoImage->readEXIF();
+    m_panoImage->applyEXIFValues();
+    if(m_panoImage->getCropFactor()<=0)
     {
         m_panoImage->readCropfactorFromDB();
     };
