@@ -28,8 +28,6 @@
 
 #include "base_wx/wxImageCache.h"
 
-using namespace HuginBase;
-
 // forward declarations, to save the #include statements
 class ImagesTreeCtrl;
 
@@ -44,7 +42,7 @@ class ImagesPanel: public wxPanel, public HuginBase::PanoramaObserver
 public:
     ImagesPanel();
 
-    bool Create(wxWindow* parent, wxWindowID id = wxID_ANY, const wxPoint& pos = wxDefaultPosition, const wxSize& size = wxDefaultSize, long style = wxTAB_TRAVERSAL, const wxString& name = wxT("panel"));
+    bool Create(wxWindow* parent, wxWindowID id = wxID_ANY, const wxPoint& pos = wxDefaultPosition, const wxSize& size = wxDefaultSize, long style = wxTAB_TRAVERSAL, const wxString& name = "panel");
 
     void Init(HuginBase::Panorama * pano);
 
@@ -79,6 +77,12 @@ public:
     void SetGuiLevel(GuiLevel newGuiLevel);
     /** return the currently selected optimizer setting as string from the drop down list box */
     wxString GetCurrentOptimizerString();
+    /** run the cp generator with the given setting on selected images */
+    void RunCPGenerator(CPDetectorSetting &setting, const HuginBase::UIntSet& img);
+    /** runs the currently selected cp generator on given images */
+    void RunCPGenerator(const HuginBase::UIntSet& img);
+    /** return the currently selected cp generator description */
+    const wxString GetSelectedCPGenerator();
 protected:
     /** event handler for geometric optimizer */
     void OnOptimizeButton(wxCommandEvent &e);
@@ -90,7 +94,7 @@ private:
     void OnSize(wxSizeEvent & e);
 
     /** the model */
-    Panorama * m_pano;
+    HuginBase::Panorama * m_pano;
 
     /** control point detection event handler*/
     void CPGenerate(wxCommandEvent & e);
@@ -158,13 +162,13 @@ private:
 
     wxButton * m_matchingButton;
     wxChoice *m_CPDetectorChoice;
+    wxChoice* m_groupModeChoice;
     //storing for different cp detector settings
     CPDetectorConfig cpdetector_config;
 
     GuiLevel m_guiLevel;
     int m_degDigits;
 
-    DECLARE_EVENT_TABLE()
     DECLARE_DYNAMIC_CLASS(ImagesPanel)
 };
 
