@@ -20,10 +20,8 @@
  *
  */
 
-#ifdef __WXMAC__
 #include "panoinc_WX.h"
 #include "panoinc.h"
-#endif
 
 #include "VertexCoordRemapper.h"
 #include <math.h>
@@ -627,8 +625,6 @@ void VertexCoordRemapper::TestSubdivide(unsigned int node_id)
             case HuginBase::PanoramaOptions::LAMBERT:
             case HuginBase::PanoramaOptions::MILLER_CYLINDRICAL:
             case HuginBase::PanoramaOptions::PANINI:
-			case HuginBase::PanoramaOptions::BIPLANE:
-			case HuginBase::PanoramaOptions::TRIPLANE:
             case HuginBase::PanoramaOptions::GENERAL_PANINI:
                 // Cylinderical-like projections have the seam across the left
                 // and right edge. We'll take any face within the middle third
