@@ -69,6 +69,8 @@ public:
     wxString path;
     //project output prefix path and filename
     wxString prefix;
+    // user defined output or assistant
+    wxString userDefindSequence;
     //last modification date and time of project
     wxDateTime modDate;
     //project options
@@ -79,7 +81,7 @@ public:
     bool isAligned;
 
     //Constructor for project files
-    Project(wxString pth,wxString pfx,Project::Target newTarget=STITCHING);
+    Project(wxString pth, wxString pfx, wxString newUserDefinedSequence = wxEmptyString, Project::Target newTarget = STITCHING);
     //Constructor for applications
     explicit Project(wxString command);
     //Returns status of project in string form
