@@ -28,12 +28,8 @@
 #include "hugin_config.h"
 #include <map>
 #include <vector>
-#include "hugin_utils/shared_ptr.h"
-#ifdef HAVE_CXX11
+#include <memory>
 #include <functional>
-#else
-#include <boost/function.hpp>
-#endif
 #include <vigra/stdimage.hxx>
 #include <vigra/imageinfo.hxx>
 #include <hugin_utils/utils.h>
@@ -58,11 +54,11 @@ class IMPEX ImageCache
 
     public:
         /// use reference counted pointers
-        typedef sharedPtrNamespace::shared_ptr<vigra::BRGBImage> ImageCacheRGB8Ptr;
-        typedef sharedPtrNamespace::shared_ptr<vigra::UInt16RGBImage> ImageCacheRGB16Ptr;
-        typedef sharedPtrNamespace::shared_ptr<vigra::FRGBImage> ImageCacheRGBFloatPtr;
-        typedef sharedPtrNamespace::shared_ptr<vigra::BImage> ImageCache8Ptr;
-        typedef sharedPtrNamespace::shared_ptr<vigra::ImageImportInfo::ICCProfile> ImageCacheICCProfile;
+        typedef std::shared_ptr<vigra::BRGBImage> ImageCacheRGB8Ptr;
+        typedef std::shared_ptr<vigra::UInt16RGBImage> ImageCacheRGB16Ptr;
+        typedef std::shared_ptr<vigra::FRGBImage> ImageCacheRGBFloatPtr;
+        typedef std::shared_ptr<vigra::BImage> ImageCache8Ptr;
+        typedef std::shared_ptr<vigra::ImageImportInfo::ICCProfile> ImageCacheICCProfile;
 
         /** information about an image inside the cache */
         struct IMPEX Entry
@@ -96,8 +92,8 @@ class IMPEX ImageCache
                       ImageCache8Ptr & imgMask,
                       ImageCacheICCProfile & ICCProfile,
                       const std::string & typ)
-                  : image8(img), image16(img16), imageFloat(imgFloat), mask(imgMask), origType(typ), lastAccess(0),
-                    iccProfile(ICCProfile)
+                  : image8(img), image16(img16), imageFloat(imgFloat), mask(imgMask),
+                    iccProfile(ICCProfile), origType(typ), lastAccess(0)
                 { 
                         DEBUG_TRACE("Constructing ImageCache::Entry");
                 };
@@ -109,11 +105,11 @@ class IMPEX ImageCache
                 };
 
                 ///
-                ImageCacheRGB8Ptr get8BitImage();
+                ImageCacheRGB8Ptr get8BitImage(int desiredMapping = -1);
         };
 
         /** a shared pointer to the entry */
-        typedef sharedPtrNamespace::shared_ptr<Entry> EntryPtr;
+        typedef std::shared_ptr<Entry> EntryPtr;
         
         /** Request for an image to load
          *  Connect to the ready signal so when the image loads you can respond.
@@ -132,11 +128,7 @@ class IMPEX ImageCache
                  *  The image could be freed after the signal fires, but keeping
                  *  the EntryPtr prevents this.
                  */
-#ifdef HAVE_CXX11
                 std::vector <std::function<void(EntryPtr, std::string, bool)>> ready;
-#else
-                std::vector <boost::function<void(EntryPtr, std::string, bool)> > ready;
-#endif
                 bool getIsSmall() const
                     {return m_isSmall;};
                 const std::string & getFilename() const
@@ -156,13 +148,13 @@ class IMPEX ImageCache
          *
          * It is reference counted, so you can freely copy and delete it.
          */
-        typedef sharedPtrNamespace::shared_ptr<Request> RequestPtr;
+        typedef std::shared_ptr<Request> RequestPtr;
 
     private:
         // ctor. private, nobody execpt us can create an instance.
         ImageCache()
-            : m_progress(NULL), m_accessCounter(0),
-              asyncLoadCompleteSignal(0), upperBound(100*1024*1024l)
+            : asyncLoadCompleteSignal(0), upperBound(100*1024*1024ull),
+              m_progress(NULL), m_accessCounter(0)
         {};
         
     public:
@@ -261,7 +253,7 @@ class IMPEX ImageCache
         void softFlush();
 		/** sets the upper limit, which is used by softFlush() 
 		 */
-		void SetUpperLimit(long newUpperLimit) { upperBound=newUpperLimit; };
+		void SetUpperLimit(const unsigned long long newUpperLimit) { upperBound=newUpperLimit; };
         
         /** Signal for when a asynchronous load completes.
          *  If you use the requestAsync functions, ensure there is something
@@ -283,28 +275,22 @@ class IMPEX ImageCache
          *  @param entry the EntryPtr from the ImageLoadedEvent.
          */
         void postEvent(RequestPtr request, EntryPtr entry);
+        
+        /** Removes the given RequestPtr from queue, 
+         *  Call from main GUI thread when an image could not loaded 
+         *
+         *  @param request The RequestPtr from the ImageLoadedEvent.
+         */
+        void removeRequest(RequestPtr request);
 
     private:
-        long upperBound;
+        unsigned long long upperBound;
 
         template <class SrcPixelType,
                   class DestIterator, class DestAccessor>
         static void importAndConvertImage(const vigra::ImageImportInfo& info,
                                    vigra::pair<DestIterator, DestAccessor> dest,
                                    const std::string& type);
-        
-    //    template <class SrcPixelType,
-    //              class DestIterator, class DestAccessor>
-    //    void importAndConvertGrayImage(const ImageImportInfo& info,
-    //                                   vigra::pair<DestIterator, DestAccessor> dest,
-    //                                   wxString type);
-        
-    //    template <class SrcPixelType,
-    //              class DestIterator, class DestAccessor>
-    //    void importAndConvertGrayAlphaImage(const ImageImportInfo & info,
-    //                                        vigra::pair<DestIterator, DestAccessor> dest,
-    //                                        wxString type);
-        
         template <class SrcPixelType,
                   class DestIterator, class DestAccessor,
                   class MaskIterator, class MaskAccessor>
