@@ -16,8 +16,8 @@
  *  General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public
- *  License along with this software; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ *  License along with this software. If not, see
+ *  <http://www.gnu.org/licenses/>.
  *
  */
 
@@ -335,6 +335,7 @@ typedef PTOVariableConverterNoOp PTOVariableConverterForExifDate;
 typedef PTOVariableConverterNoOp PTOVariableConverterForExifExposureMode;
 typedef PTOVariableConverterNoOp PTOVariableConverterForExifRedBalance;
 typedef PTOVariableConverterNoOp PTOVariableConverterForExifBlueBalance;
+typedef PTOVariableConverterNoOp PTOVariableConverterForFileMetadata;
 
 #if 0
 //panotools variables, currently not used
