@@ -64,10 +64,10 @@ static void usage(const char* name)
          << std::endl
          << "Usage: " << name  << " [options] -o output project_file (image files)" << std::endl
          << "  Options: " << std::endl
-         << "      -c         create coordinate images (only TIFF_m output)" << std::endl
-         << "      -v         verbose output" << std::endl
-         << "      -d|--debug print detailed output for gpu processing" << std::endl
-         << "      -g|--gpu   perform image remapping on the GPU" << std::endl
+         << "      -c            create coordinate images (only TIFF_m output)" << std::endl
+         << "      -v|--verbose  verbose output" << std::endl
+         << "      -d|--debug    print detailed output for gpu processing" << std::endl
+         << "      -g|--gpu      perform image remapping on the GPU" << std::endl
          << std::endl
          << "  The following options can be used to override settings in the project file:" << std::endl
          << "      -i num     remap only image with number num" << std::endl
@@ -162,6 +162,7 @@ int main(int argc, char* argv[])
         { "output-range-compression", required_argument, NULL, RANGECOMPRESSION },
         { "help", no_argument, NULL, 'h'},
         { "debug", no_argument, NULL, 'd'},
+        { "verbose", no_argument, NULL, 'v'},
         { "output", required_argument, NULL, 'o'},
         0
     };
@@ -304,7 +305,13 @@ int main(int argc, char* argv[])
                 compression=hugin_utils::toupper(compression);
                 break;
             case 'g':
+#if defined __APPLE__ && defined __aarch64__
+                // disable GPU remapping on ARM Macs, GPU code is not working on these systems
+                useGPU = false;
+                std::cout << "WARNING: GPU remapping is not supported on ARM Macs. Switching back to CPU remapping." << std::endl;
+#else
                 useGPU = true;
+#endif
                 break;
             case 'd':
                 vigra_ext::SetGPUDebugMessages(true);
@@ -353,19 +360,10 @@ int main(int argc, char* argv[])
     TIFFSetWarningHandler(0);
 
     HuginBase::Panorama pano;
-    std::ifstream prjfile(scriptFile);
-    if (prjfile.bad())
+    if (!pano.ReadPTOFile(scriptFile, hugin_utils::getPathPrefix(scriptFile)))
     {
-        std::cerr << "could not open script : " << scriptFile << std::endl;
         exit(1);
-    }
-    pano.setFilePrefix(hugin_utils::getPathPrefix(scriptFile));
-    AppBase::DocumentData::ReadWriteError err = pano.readData(prjfile);
-    if (err != AppBase::DocumentData::SUCCESSFUL)
-    {
-        std::cerr << "error while parsing panos tool script: " << scriptFile << std::endl;
-        exit(1);
-    }
+    };
 
     if ( nCmdLineImgs > 0)
     {
