@@ -29,9 +29,6 @@
 #include <fstream>
 #include <sstream>
 #include <getopt.h>
-#ifndef _WIN32
-#include <unistd.h>
-#endif
 #include <panodata/Panorama.h>
 
 static void usage(const char* name)
@@ -61,9 +58,8 @@ int main(int argc, char* argv[])
     };
 
     int c;
-    int optionIndex = 0;
     std::string output;
-    while ((c = getopt_long (argc, argv, optstring, longOptions,&optionIndex)) != -1)
+    while ((c = getopt_long (argc, argv, optstring, longOptions,nullptr)) != -1)
     {
         switch (c)
         {
@@ -73,73 +69,58 @@ int main(int argc, char* argv[])
             case 'h':
                 usage(hugin_utils::stripPath(argv[0]).c_str());
                 return 0;
+            case ':':
             case '?':
+                // missing argument or invalid switch
+                return 1;
                 break;
             default:
-                abort ();
+                // this should not happen
+                abort();
         }
     }
 
     if (argc - optind < 2)
     {
-        std::cout << "Warning: pto_merge requires at least 2 project files" << std::endl << std::endl;
-        usage(hugin_utils::stripPath(argv[0]).c_str());
+        std::cerr << hugin_utils::stripPath(argv[0]) << ": at least 2 project files needed" << std::endl << std::endl;
         return 1;
     };
 
     std::string input=argv[optind];
     // read panorama
     HuginBase::Panorama pano;
-    std::ifstream prjfile(input.c_str());
-    if (!prjfile.good())
+    if (!pano.ReadPTOFile(input, hugin_utils::getPathPrefix(input)))
     {
-        std::cerr << "could not open script : " << input << std::endl;
         return 1;
-    }
-    pano.setFilePrefix(hugin_utils::getPathPrefix(input));
-    AppBase::DocumentData::ReadWriteError err = pano.readData(prjfile);
-    if (err != AppBase::DocumentData::SUCCESSFUL)
-    {
-        std::cerr << "error while parsing panos tool script: " << input << std::endl;
-        std::cerr << "AppBase::DocumentData::ReadWriteError code: " << err << std::endl;
-        return 1;
-    }
+    };
 
     optind++;
     while(optind<argc)
     {
         HuginBase::Panorama pano2;
-        std::string input2=argv[optind];
-        std::ifstream prjfile2(input2.c_str());
-        if (!prjfile2.good())
+        const std::string input2=argv[optind];
+        if (!pano2.ReadPTOFile(input2, hugin_utils::getPathPrefix(input2)))
         {
-            std::cerr << "could not open script : " << input << std::endl;
             return 1;
-        }
-        pano2.setFilePrefix(hugin_utils::getPathPrefix(input2));
-        AppBase::DocumentData::ReadWriteError err = pano2.readData(prjfile2);
-        if (err != AppBase::DocumentData::SUCCESSFUL)
+        };
+        // read EXIF data, needed for lens detection in merged pano
+        for (size_t i = 0; i < pano.getNrOfImages(); ++i)
         {
-            std::cerr << "error while parsing panos tool script: " << input << std::endl;
-            std::cerr << "AppBase::DocumentData::ReadWriteError code: " << err << std::endl;
-            return 1;
-        }
+            HuginBase::SrcPanoImage srcImg(pano.getImage(i));
+            srcImg.readEXIF();
+            pano.setSrcImage(i, srcImg);
+        };
         pano.mergePanorama(pano2);
         optind++;
     };
 
     //write output
-    HuginBase::OptimizeVector optvec = pano.getOptimizeVector();
-    HuginBase::UIntSet imgs;
-    fill_set(imgs,0, pano.getNrOfImages()-1);
     // Set output .pto filename if not given
-    if (output=="")
+    output = hugin_utils::GetOutputFilename(output, input, "merge");
+    if (pano.WritePTOFile(output, hugin_utils::getPathPrefix(output)))
     {
-        output=input.substr(0,input.length()-4).append("_merge.pto");
-    }
-    std::ofstream of(output.c_str());
-    pano.printPanoramaScript(of, optvec, pano.getOptions(), imgs, false, hugin_utils::getPathPrefix(input));
+        std::cout << std::endl << "Written project file " << output << std::endl;
+    };
 
-    std::cout << std::endl << "Written output to " << output << std::endl;
     return 0;
 }
