@@ -203,7 +203,7 @@ static void usage(const char* name)
  *  LoadAndMergeImage would require the full canvas size for loading, so using this specialized version
  *  which is using the cropped intermediates images */
 template<class ImageType, class MaskType>
-bool ResaveImage(const vigra::ImageImportInfo& importInfo, vigra::ImageExportInfo& exportInfo)
+bool ResaveImageFill(const vigra::ImageImportInfo& importInfo, vigra::ImageExportInfo& exportInfo, bool fillEdges, bool doWrap)
 {
     ImageType image(importInfo.size());
     MaskType mask(image.size());
@@ -213,6 +213,8 @@ bool ResaveImage(const vigra::ImageImportInfo& importInfo, vigra::ImageExportInf
         vigra::importImage(importInfo, vigra::destImage(image));
         // init mask
         vigra::initImage(vigra::destImageRange(mask), vigra_ext::LUTTraits<typename MaskType::value_type>::max());
+        // no alpha channel, so we can't detect empty edges
+        fillEdges = false;
         ++numBands;
     }
     else
@@ -227,7 +229,30 @@ bool ResaveImage(const vigra::ImageImportInfo& importInfo, vigra::ImageExportInf
             return false;
         };
     };
-
+    std::cout << "Loaded " << importInfo.getFileName() << std::endl;
+    if (fillEdges)
+    {
+        const typename MaskType::PixelType maskZero = vigra_ext::LUTTraits<typename MaskType::PixelType>::min();
+        const typename MaskType::PixelType maskMax = vigra_ext::LUTTraits<typename MaskType::PixelType>::max();
+        ImageType dummyImage(image.size(), vigra_ext::LUTTraits<typename ImageType::PixelType>::max());
+        // invert mask
+        MaskType dummyMask(image.size());
+        vigra::omp::transformImage(vigra::srcImageRange(mask), vigra::destImage(dummyMask), vigra::functor::ifThenElse(vigra::functor::Arg1() > vigra::functor::Param(maskMax / 2), vigra::functor::Param(maskZero), vigra::functor::Param(maskMax)));
+        // create label
+        vigra::BImage label(image.size());
+        vigra::omp::transformImage(vigra::srcImageRange(mask), vigra::destImage(label), vigra::functor::ifThenElse(vigra::functor::Arg1() > vigra::functor::Param(maskMax / 2), vigra::functor::Param(1), vigra::functor::Param(5)));
+        // check that we have uncovered labels
+        vigra::FindMinMax<vigra::UInt8> labelMinmax;
+        vigra::inspectImage(vigra::srcImageRange(label), labelMinmax);
+        if (labelMinmax.max > 1)
+        {
+            std::cout << "Filling edges" << std::endl;
+            // fill edges
+            vigra_ext::PoissonBlend(image, dummyImage, dummyMask, label, vigra::Point2D(0, 0), doWrap);
+            // now we need to update the mask
+            vigra::initImage(vigra::destImageRange(mask), maskMax);
+        };
+    };
     const vigra::Rect2D roi(vigra::Point2D(0, 0), image.size());
     return SaveFinalImage(image, mask, importInfo.getPixelType(), numBands, exportInfo, roi);
 };
@@ -367,27 +392,27 @@ int main(int argc, char* argv[])
         {
             if (pixeltype == "UINT8")
             {
-                success = ResaveImage<vigra::BRGBImage, vigra::BImage>(imageInfo, exportInfo);
+                success = ResaveImageFill<vigra::BRGBImage, vigra::BImage>(imageInfo, exportInfo, !hardSeam, wraparound);
             }
             else if (pixeltype == "INT16")
             {
-                success = ResaveImage<vigra::Int16RGBImage, vigra::Int16Image>(imageInfo, exportInfo);
+                success = ResaveImageFill<vigra::Int16RGBImage, vigra::Int16Image>(imageInfo, exportInfo, !hardSeam, wraparound);
             }
             else if (pixeltype == "UINT16")
             {
-                success = ResaveImage<vigra::UInt16RGBImage, vigra::UInt16Image>(imageInfo, exportInfo);
+                success = ResaveImageFill<vigra::UInt16RGBImage, vigra::UInt16Image>(imageInfo, exportInfo, !hardSeam, wraparound);
             }
             else if (pixeltype == "INT32")
             {
-                success = ResaveImage<vigra::Int32RGBImage, vigra::UInt32Image>(imageInfo, exportInfo);
+                success = ResaveImageFill<vigra::Int32RGBImage, vigra::UInt32Image>(imageInfo, exportInfo, !hardSeam, wraparound);
             }
             else if (pixeltype == "UINT32")
             {
-                success = ResaveImage<vigra::UInt32RGBImage, vigra::UInt32Image>(imageInfo, exportInfo);
+                success = ResaveImageFill<vigra::UInt32RGBImage, vigra::UInt32Image>(imageInfo, exportInfo, !hardSeam, wraparound);
             }
             else if (pixeltype == "FLOAT")
             {
-                success = ResaveImage<vigra::FRGBImage, vigra::FImage>(imageInfo, exportInfo);
+                success = ResaveImageFill<vigra::FRGBImage, vigra::FImage>(imageInfo, exportInfo, !hardSeam, wraparound);
             }
             else
             {
@@ -399,27 +424,27 @@ int main(int argc, char* argv[])
             //grayscale images
             if (pixeltype == "UINT8")
             {
-                success = ResaveImage<vigra::BImage, vigra::BImage>(imageInfo, exportInfo);
+                success = ResaveImageFill<vigra::BImage, vigra::BImage>(imageInfo, exportInfo, !hardSeam, wraparound);
             }
             else if (pixeltype == "INT16")
             {
-                success = ResaveImage<vigra::Int16Image, vigra::Int16Image>(imageInfo, exportInfo);
+                success = ResaveImageFill<vigra::Int16Image, vigra::Int16Image>(imageInfo, exportInfo, !hardSeam, wraparound);
             }
             else if (pixeltype == "UINT16")
             {
-                success = ResaveImage<vigra::UInt16Image, vigra::UInt16Image>(imageInfo, exportInfo);
+                success = ResaveImageFill<vigra::UInt16Image, vigra::UInt16Image>(imageInfo, exportInfo, !hardSeam, wraparound);
             }
             else if (pixeltype == "INT32")
             {
-                success = ResaveImage<vigra::Int32Image, vigra::Int32Image>(imageInfo, exportInfo);
+                success = ResaveImageFill<vigra::Int32Image, vigra::Int32Image>(imageInfo, exportInfo, !hardSeam, wraparound);
             }
             else if (pixeltype == "UINT32")
             {
-                success = ResaveImage<vigra::UInt32Image, vigra::UInt32Image>(imageInfo, exportInfo);
+                success = ResaveImageFill<vigra::UInt32Image, vigra::UInt32Image>(imageInfo, exportInfo, !hardSeam, wraparound);
             }
             else if (pixeltype == "FLOAT")
             {
-                success = ResaveImage<vigra::FImage, vigra::FImage>(imageInfo, exportInfo);
+                success = ResaveImageFill<vigra::FImage, vigra::FImage>(imageInfo, exportInfo, !hardSeam, wraparound);
             }
             else
             {
